@@ -238,7 +238,7 @@ summary.ctStanFit<-function(object,timeinterval=1,digits=4,parmatrices=TRUE,prio
   
   out$popmeans=round(popmeans,digits=digits)
   
-  out$popNote=paste0('popmeans are reported as specified in ctModel -- covariance related matrices are in sd / unconstrained correlation form -- see $parmatrices for simpler interpretations!')
+  out$popNote=paste0('covariance pars in sd / unconstrained cor form, see $parmatrices for cor/cov.')
   
   if(optimize) {
     
